@@ -37,6 +37,7 @@
 #define PATH_ICON_NA 		PIXMAPSDIR"emifreq-icon-na.png"
 #define PATH_ICON_POWERSAVE 	PIXMAPSDIR"emifreq-icon-powersave.png"
 #define PATH_ICON_PERFORMANCE 	PIXMAPSDIR"emifreq-icon-performance.png"
+#define PATH_ICON_ONDEMAND	PIXMAPSDIR"emifreq-icon-ondemand.png"
 #define PATH_ICON_1 		PIXMAPSDIR"emifreq-icon-1.png"
 #define PATH_ICON_2 		PIXMAPSDIR"emifreq-icon-2.png"
 #define PATH_ICON_3 		PIXMAPSDIR"emifreq-icon-3.png"
@@ -45,6 +46,7 @@
 #define PATH_ICON_NA_V 		PIXMAPSDIR"emifreq-icon-na-v.png"
 #define PATH_ICON_POWERSAVE_V   PIXMAPSDIR"emifreq-icon-powersave-v.png"
 #define PATH_ICON_PERFORMANCE_V PIXMAPSDIR"emifreq-icon-performance-v.png"
+#define PATH_ICON_ONDEMAND_V	PIXMAPSDIR"emifreq-icon-ondemand-v.png"
 #define PATH_ICON_1_V		PIXMAPSDIR"emifreq-icon-1-v.png"
 #define PATH_ICON_2_V		PIXMAPSDIR"emifreq-icon-2-v.png"
 #define PATH_ICON_3_V		PIXMAPSDIR"emifreq-icon-3-v.png"
@@ -169,6 +171,8 @@ get_pixbuf_from_usage (EmiFreqApplet *applet, float usage) {
 
 	if (applet_is_non_available (applet) || usage == -1)
 		path = horizontal ? PATH_ICON_NA : PATH_ICON_NA_V;
+	else if (usage == -2.0)
+		path = horizontal ? PATH_ICON_ONDEMAND : PATH_ICON_ONDEMAND_V;
 	else if (usage == 0.0)
 		path = horizontal ? PATH_ICON_POWERSAVE : PATH_ICON_POWERSAVE_V;
 	else if (usage == 100.0)
@@ -229,17 +233,14 @@ static void
 update_applet_icon (EmiFreqApplet *applet)
 {
 	GdkPixbuf *pixbuf;
+	float usage;
 
 	g_return_if_fail (applet != NULL);
 	g_return_if_fail (applet->icon != NULL);
 
-	{
-		float usage = ef_backend_get_usage ();
+	usage = ef_backend_get_usage ();
 
-g_printf ("updating icon w/ usage = %.2f\n", usage);
-
-		pixbuf = get_pixbuf_from_usage (applet, usage);
-	}
+	pixbuf = get_pixbuf_from_usage (applet, usage);
 
 	if (pixbuf != NULL) {
 		gtk_image_set_from_pixbuf (GTK_IMAGE (applet->icon), pixbuf);
@@ -263,7 +264,7 @@ update_applet_tooltip (EmiFreqApplet *applet)
 	else {
 		/* Note: the init is important. Let this like that */
 		char *temp_text = "";
-		char *governor = ef_backend_get_governor_name ();
+		const char *governor = ef_backend_get_profile_name ();
 		int temp = ef_backend_get_temperature (applet->enable_metric);
 
 		if (!applet->show_temp && temp != -1) {
@@ -275,11 +276,11 @@ update_applet_tooltip (EmiFreqApplet *applet)
 		}
 
 		if (f < 1000000)
-			/* the format is <governor name>, <frequency> and <the temperature field just above>
+			/* the format is <profile name>, <frequency> and <the temperature field just above>
 			   translators please tell me if it can't work like that for a given language */
-			text = g_strdup_printf (_("%s governor, %d Mhz%s"), governor, f / 1000, temp_text);
+			text = g_strdup_printf (_("%s, %d Mhz%s"), governor, f / 1000, temp_text);
 		else
-			text = g_strdup_printf (_("%s governor, %.1f Ghz%s"), governor, f / 1000000.0, temp_text);
+			text = g_strdup_printf (_("%s, %.1f Ghz%s"), governor, f / 1000000.0, temp_text);
 
 		if (strlen (temp_text) > 0)
 			g_free (temp_text);
